Skip to contents

Tools for processing and analyzing raw excitation-emission matrices (EEMs) and absorbance data. Includes functions for data cleaning, quality assurance, calculation of indices, and generating visualizations. Builds upon the 'eemR' and 'staRdom' packages to create a more streamlined and automated workflow that ensures consistent analysis and simplify the coding required to process the data.

Author

Maintainer: Katie A. Wampler katie.wampler@oregonstate.edu (ORCID)

Authors: