Skip to contents

Processed version of example_eems() using eemanalyzeR.

Usage

example_processed_eems

Format

An eemlist with four samples:

  • B1S1ExampleBlankSEM: Fluorescence measured for a sample of Type 1 water

  • B1S2ExampleTeaStdSEM: Fluorescence measured for a sample of dilute unsweetened tea

  • B1S3ExampleSampleSEM: Fluorescence measured for a sample of stream water from Oregon, USA

  • ManualExampleTeaWaterfallPlotSample: Fluorescence measured for a sample of dilute unsweetened tea

Oregon State University Forest Ecohydrology and Watershed Sciences Lab (2022-11-14)