Calculates commonly used absorbance and fluorescence optical indices from eemlist and abslist.
These indices are those commonly used by the U.S. Geological Survey.
For detailed descriptions and references, see Hansen et al. 2018 (Tables 1 and 8).
Hansen, A. M., Fleck, J., Kraus, T. E. C., Downing, B. D., von Dessonneck, T., & Bergamaschi, B. (2018). Procedures for using the Horiba Scientific Aqualog® fluorometer to measure absorbance and fluorescence from dissolved organic matter (USGS Numbered Series No. 2018-1096). U.S. Geological Survey. doi:10.3133/ofr20181096
Arguments
- eemlist
An
eemlistobject.- abslist
An
abslistobject.- cuvle
Cuvette (path) length in cm.
- qaqc_dir
File path to the QAQC files generated with
create_mdl()andcreate_std(). Default is NA, which results in NO QAQC CHECKS.
Value
A list with two elements:
eem_index: a
data.frameof all fluorescence indices. Each row corresponds to a single index for a sample.abs_index: a
data.frameof all absorbance indices. Each row corresponds to a single index for a sample.
Each data.frame contains the following columns:
sample_id: sample identifier for the sample (if provided, otherwise uses sample: the sample's file name)
sample_name: sample name or description (if provided, otherwise uses sample: the sample's file name)
index: name of the index
value: calculated value of the index
Note
If absorbance is not at a 1 nm interval, it will be interpolated using
zoo::na.approx(), which fills in missing values using linear interpolation.If EEM data is not at a 1 nm interval, fluorescence will be interpolated using
pracma::interp2().
Examples
indices <- usgs_indices(
example_processed_eems,
example_processed_abs,
qaqc_dir = system.file("extdata", package = "eemanalyzeR")
)