Sometimes it is easier to subset an EEM matrix if it is in a long format.
This function will take an EEM matrix and turn it into a data.frame or,
if it is a data.frame, convert it to an eem object.
Arguments
- eem
An object of class
eemor adata.framewith three columns:ex,em, andfluor.- file
Optional. File path to the EEM data including the data file name; only used if
eemis adata.frame.- sample
Optional. The name of the EEM sample; only used if
eemis adata.frame.- location
Optional. The path to the directory where the file is located; only used if
eemis adata.frame.
Value
Converts between an object of class eem and a data.frame with three columns:
ex: the excitation wavelengthsem: the emission wavelengthsfluor: the fluorescence values