Wrapper function that combines multiple EEM processing steps into a streamlined workflow. The processing steps include:
subtract_blank(): subtracts blank samples from the EEMsremove_scattering(): removes scattering lines with optional interpolationife_correct(): corrects for inner filter effectsraman_normalize(): normalizes fluorescence intensity to Raman unitscorrect_dilution(): adjusts intensity for sample dilutionseemR::eem_cut(): clips the excitation–emission matrices to the region of interest
Arguments
- eemlist
An
eemlistobject.- abslist
An
abslistobject.- ex_clip
Numeric vector of length two specifying the minimum and maximum excitation wavelengths to keep.
- em_clip
Numeric vector of length two specifying the minimum and maximum emission wavelengths to keep.
- type
Logical vector of length four indicating which scattering lines to remove. The order is "raman1", "raman2", "rayleigh1", "rayleigh2".
- width
Numeric vector of length four specifying the width of scattering lines to remove (nm). Same order as
type.- interpolate
Logical vector of length four indicating which scattering lines to interpolate. Same order as
type.- method
Numeric (0–4) specifying the interpolation method to use. Default is 1. See
staRdom::eem_interp()for details.- cores
Integer specifying the number of cores for parallel computation during interpolation.
- cuvle
Cuvette (path) length in cm.
Details
Metadata
Absorbance and EEM data are linked via the meta_name in the metadata.
Metadata must already be added to the samples using add_metadata().
Tracking Processing Steps
Processing steps are tracked in two ways:
Each sample has an attribute that records its processing steps. You can view this using
attributes(eem).Overall processing steps are recorded in a
readmevariable (accessible usingprint_readme()) or exported as thereadme.txtfile usingexport_data().
Examples
eemlist <- add_metadata(metadata, example_eems)
abslist <- add_metadata(metadata, example_abs)
blanklist <- subset_type(eemlist, "iblank")
eemlist <- add_blanks(eemlist, blanklist)
corrected_eem <- process_eem(eemlist, abslist)
plot(corrected_eem)