Normalizes the fluorescence intensity of EEMs to Raman Units (R.U.) based on the area of the water Raman peak (Lawaetz and Stedmon, 2009).
Lawaetz, A. J., & Stedmon, C. A. (2009). Fluorescence Intensity Calibration Using the Raman Scatter Peak of Water. Applied Spectroscopy, 63(8), 936-940. doi:10.1366/000370209788964548
Details
The function uses the Raman peak area provided in the metadata to normalize the EEMs.
Therefore, metadata must be added to the samples prior to normalization using
add_metadata().
Examples
eemlist <- add_metadata(metadata, example_eems)
correct_eem <- raman_normalize(eemlist)