Returns the data processing configuration settings for this R session back to package defaults.
Details
This allows the user to return the data processing settings back to the default configuration of the eemanalyzeR package. These defaults are documented in data.R under "default_config". This function is provided in case the user needs to return back to default processing settings after experimenting with modifying the settings using `modify_config`.