R/pkg-env.R
validate_config.Rd
Checks that all settings in the eemanalyzeR config are valid options and warns user if not
validate_config(env = .pkgenv)
environment where to find the config. Defaults to the package environment
invisibly returns TRUE if the configuration is valid, otherwise returns an error
# Example validation validate_config()